# Sorcha Add-ons


[![ci](https://github.com/dirac-institute/sorcha-addons/actions/workflows/smoke-test.yml/badge.svg)](https://github.com/dirac-institute/sorcha-addons/actions/workflows/smoke-test.yml)
[![pytest](https://github.com/dirac-institute/sorcha-addons/actions/workflows/testing-and-coverage.yml/badge.svg)](https://github.com/dirac-institute/sorcha-addons/actions/workflows/testing-and-coverage.yml)
[![Documentation Status](https://readthedocs.org/projects/sorcha-addons/badge/?version=latest)](https://sorcha-addons.readthedocs.io/en/latest/?badge=latest)

[![Template](https://img.shields.io/badge/Template-LINCC%20Frameworks%20Python%20Project%20Template-brightgreen)](https://lincc-ppt.readthedocs.io/en/latest/)

This is a repository for community generated light curve and cometary activity
functions for the [sorcha](https://github.com/dirac-institute/sorcha) Solar
System survey simulator software package.

